@@ -9,14 +9,17 @@ use parent qw(
 sub ATB_DATA() { 1 };
 
 sub determine {
-	my ($self, $prefix) = @_;
+	my ($self, $prefix, $data) = @_;
 
 	my @values = ();
 	my $i = 0;
-	foreach my $name (@{$self->[ATB_DATA]}) {
+#	my %seen = ();
+	foreach my $name (@$data) {
+#		next if(exists($seen{$name}));
+#		$seen{$name} = 1;
 		push(@values, ["$prefix$name", $i++]);
 	}
 	return(\@values);
 }
 
-1;
\ No newline at end of file
+1;
